/**
 * DRV8835
 * 
 * (c)2020 Futoshi Sumikawa.
 * 
 *  TMR2
 *    -Hardware Settings
 *      Enable Timer
 *        Clock prescaler 1:10
 *        Postscaler 1:4
 *    -Timer Period
 *      Requested Period: 10ms
 *      Actual Period: 10ms
 *
 *  PWM5
 *    -Hardware Settings
 *      Enable PWM5
 *      Select a Timer: Timer2
 *
 *  PWM6
 *    -Hardware Settings
 *      Enable PWM6
 *      Select a Timer: Timer2
 * 
 */
#include "drv8835.h"

int8_t _drvBalanceForward = 0;
int8_t _drvBalanceBack = 0;
int8_t _drvBalanceRight = 0;
int8_t _drvBalanceLeft = 0;



void drvSetBalanceForward(int8_t balance) {
    _drvBalanceForward = balance;
}
void drvSetBalanceBack(int8_t balance) {
    _drvBalanceBack = balance;
}
void drvSetBalanceRight(int8_t balance) {
    _drvBalanceRight = balance;
}
void drvSetBalanceLeft(int8_t balance) {
    _drvBalanceLeft = balance;
}


void drvCoastA(void) {

    // AIN1:RC2 set LATRC2
    RC2PPS = 0x00;
    // AIN2:RC1 set LATRC1
    RC1PPS = 0x00;
    
    AIN1_SetLow();
    AIN2_SetLow();
}

void drvCoastB(void) {

    // BIN1:RC0 set LATRC0
    RC0PPS = 0x00;
    // BIN2:RA2 set LATRA2
    RA2PPS = 0x00;

    BIN1_SetLow();
    BIN2_SetLow();
}

void drvReverseA(void) {

    // AIN1:RC2 set LATRC2
    RC2PPS = 0x00;
    AIN1_SetLow();

    // AIN2:RC1 set PWM5
    RC1PPS = 0x02;
}

void drvReverseB(void) {

    // BIN1:RC0 set LATRC0
    RC0PPS = 0x00;
    BIN1_SetLow();

    // BIN2:RA2 set PWM6
    RA2PPS = 0x03;
}

void drvForwardA(void) {
    
    // AIN2:RC1 set LATRC1
    RC1PPS = 0x00;
    AIN2_SetLow();

    // AIN1:RC2 set PWM5
    RC2PPS = 0x02;
}

void drvForwardB(void) {

    // BIN2:RA2 set LATRA2
    RA2PPS = 0x00;
    BIN2_SetLow();

    // BIN1:RC0 set PWM6
    RC0PPS = 0x03;
}

void drvBrekeA(void) {
    // AIN2:RC1 set LATRC1
    RC1PPS = 0x00;
    // AIN1:RC2 set LATRC2
    RC2PPS = 0x00;

    AIN1_SetHigh();
    AIN2_SetHigh();
}

void drvBrekeB(void) {

    // BIN1:RC0 set LATRC0
    RC0PPS = 0x00;
    // BIN2:RA2 set LATRA2
    RA2PPS = 0x00;

    BIN1_SetHigh();
    BIN2_SetHigh();
}

void drvForward(uint16_t dutyValue) {
    PWM5_LoadDutyValue(dutyValue);
    PWM6_LoadDutyValue((uint16_t)((int16_t)dutyValue + _drvBalanceForward * 2));
    drvReverseA();
    drvForwardB();
}

void drvBack(uint16_t dutyValue) {
    PWM5_LoadDutyValue(dutyValue);
    PWM6_LoadDutyValue((uint16_t)((int16_t)dutyValue + _drvBalanceBack * 2));
    drvForwardA();
    drvReverseB();
}

void drvLeft(uint16_t dutyValue) {
    PWM5_LoadDutyValue(dutyValue);
    PWM6_LoadDutyValue((uint16_t)((int16_t)dutyValue + _drvBalanceLeft * 2));
    drvForwardA();
    drvForwardB();
}

void drvRight(uint16_t dutyValue) {
    PWM5_LoadDutyValue(dutyValue);
    PWM6_LoadDutyValue((uint16_t)((int16_t)dutyValue + _drvBalanceRight * 2));
    drvReverseA();
    drvReverseB();
}

void drvWait(void) {
    drvBrekeA();
    drvBrekeB();
}
